@@ -15,30 +15,34 @@ _factory = ArrowFactory()
 
 
 def get(*args, **kwargs):
-    ''' Implements the default :class:`ArrowFactory <arrow.factory.ArrowFactory>`
-    ``get`` method.
+    ''' Calls the default :class:`ArrowFactory <arrow.factory.ArrowFactory>` ``get`` method.
 
     '''
 
     return _factory.get(*args, **kwargs)
 
+get.__doc__ = _factory.get.__doc__
+
+
 def utcnow():
-    ''' Implements the default :class:`ArrowFactory <arrow.factory.ArrowFactory>`
-    ``utcnow`` method.
+    ''' Calls the default :class:`ArrowFactory <arrow.factory.ArrowFactory>` ``utcnow`` method.
 
     '''
 
     return _factory.utcnow()
 
+utcnow.__doc__ = _factory.utcnow.__doc__
+
 
 def now(tz=None):
-    ''' Implements the default :class:`ArrowFactory <arrow.factory.ArrowFactory>`
-    ``now`` method.
+    ''' Calls the default :class:`ArrowFactory <arrow.factory.ArrowFactory>` ``now`` method.
 
     '''
 
     return _factory.now(tz)
 
+now.__doc__ = _factory.now.__doc__
+
 
 def factory(type):
     ''' Returns an :class:`.ArrowFactory` for the specified :class:`Arrow <arrow.arrow.Arrow>`
@@ -50,6 +54,4 @@ def factory(type):
 
     return ArrowFactory(type)
 
-
 __all__ = ['get', 'utcnow', 'now', 'factory']
-
